@@ -1,5 +1,5 @@
 /* This file is part of the Zebra server.
-   Copyright (C) 2004-2013 Index Data
+   Copyright (C) Index Data
 
 Zebra is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -37,7 +37,6 @@ static void r_close(RSFD rfd);
 static void r_delete(RSET ct);
 static int r_forward(RSFD rfd, void *buf, TERMID *term, const void *untilbuf);
 static int r_read(RSFD rfd, void *buf, TERMID *term);
-static int r_write(RSFD rfd, const void *buf);
 static void r_pos(RSFD rfd, double *current, double *total);
 static void r_get_terms(RSET ct, TERMID *terms, int maxterms, int *curterm);
 
@@ -51,7 +50,7 @@ static const struct rset_control control =
     r_forward,
     r_pos,
     r_read,
-    r_write,
+    rset_no_write,
 };
 
 struct rset_prox_info {
@@ -305,12 +304,6 @@ static int r_read(RSFD rfd, void *buf, TERMID *term)
     return r_forward(rfd, buf, term, 0);
 }
 
-static int r_write(RSFD rfd, const void *buf)
-{
-    yaz_log(YLOG_FATAL, "prox set type is read-only");
-    return -1;
-}
-
 static void r_pos(RSFD rfd, double *current, double *total)
 {
     RSET ct = rfd->rset;
